ModAccess

Enum ModAccess 

pub enum ModAccess {
    World,
    Sandbox(Entity),
}
Represents the access a mod can be given to run in.

Mods can run in the world and/or in sandboxes defined by their entity.

See: Mods::enable_access

Variants



World



Sandbox(Entity)

Implementations

Source

impl ModAccess

pub fn schedules(&self, world: &World) -> ModSchedules

Resolves the schedules configured to run for this mod

pub fn filtered_access(&self, world: &World) -> FilteredAccess

Returns world access to only the entities granted by this access.

This is used by Wasvy to build mod systems that don’t conflict (can run in parallel) between different accesses.

pub fn validate(&self, world: &World) -> Result<(), String>

Validates a ModAccess is valid before invoking it

pub fn display(&self, world: &World) -> String

Like std::fmt::Display but requires world access