pub struct FunctionIndex { /* private fields */ }Expand description
Index of component methods derived from Bevy’s FunctionRegistry.
This is used by WIT generation and by the host runtime to resolve dynamic method calls.
Implementations
Sourceimpl FunctionIndex
impl FunctionIndex
Sourcepub fn build(
type_registry: &AppTypeRegistry,
function_registry: &AppFunctionRegistry,
) -> Self
pub fn build( type_registry: &AppTypeRegistry, function_registry: &AppFunctionRegistry, ) -> Self
Sourcepub fn components(&self) -> impl Iterator<Item = &str>
pub fn components(&self) -> impl Iterator<Item = &str>
Iterate over all exported component type paths.
Sourcepub fn methods_for<'a>(
&'a self,
type_path: &str,
) -> impl Iterator<Item = &'a FunctionEntry>
pub fn methods_for<'a>( &'a self, type_path: &str, ) -> impl Iterator<Item = &'a FunctionEntry>
Iterate over all methods for a component type path.
Sourcepub fn get(&self, type_path: &str, method: &str) -> Option<&FunctionEntry>
pub fn get(&self, type_path: &str, method: &str) -> Option<&FunctionEntry>
Lookup a specific method entry.
Sourcepub fn invoke(
&self,
type_path: &str,
method: &str,
target: MethodTarget<'_>,
params: &[u8],
type_registry: &AppTypeRegistry,
codec: &CodecResource,
) -> Result<Vec<u8>>
pub fn invoke( &self, type_path: &str, method: &str, target: MethodTarget<'_>, params: &[u8], type_registry: &AppTypeRegistry, codec: &CodecResource, ) -> Result<Vec<u8>>