pub enum ModDespawnBehaviour {
None,
DespawnEntities,
}Expand description
An enum that defines what happens when a mod is despawned (or reloaded)
Set this value during plugin instantiation via ModloaderPlugin::set_despawn_behaviour.
The default behaviour is to despawn all entities this mod spawned. See DespawnEntities.
Variants
None
Do nothing when a mod is despawned
DespawnEntities
The default. Despawn all entities this mod spawned.
So for example if your mod spawns a cube in the center of the scene, when this mod is hot reloaded the cube is despawned, and the newest version of the mod spawns a new cube in its place.