ModSchedule

Enum ModSchedule 

pub enum ModSchedule {
    ModStartup,
    PreUpdate,
    Update,
    PostUpdate,
    FixedPreUpdate,
    FixedUpdate,
    FixedPostUpdate,
    Custom {
        name: String,
        schedule: Interned<dyn ScheduleLabel>,
    },
}
This is an enum representing schedules in Bevy where mods can also be run.

See the docs for bevy schedules.

Call ModloaderPlugin::enable_schedule to enable new or custom schedules for mods.

None of the startup schedules (like PreStartup, Startup, etc) are included since mods can’t usually run within them, since mods take time to load and begin loading these schedules have finished running.

Variants



ModStartup

A custom schedule that runs the first time a mod is loaded.

It is a custom schedule that runs during the setup schedule (which defaults to First), see ModloaderPlugin::set_setup_schedule).

Upon being loaded, mods are guaranteed to only run this schedule once, even if other mods are loaded afterwards.



PreUpdate

See the Bevy schedule PreUpdate



Update

See the Bevy schedule Update



PostUpdate

See the Bevy schedule PostUpdate



FixedPreUpdate

See the Bevy schedule FixedPreUpdate



FixedUpdate

See the Bevy schedule FixedUpdate



FixedPostUpdate

See the Bevy schedule FixedPostUpdate



Custom

A custom schedule. See ModSchedule::new_custom for more details.

Fields

name: String
schedule: Interned<dyn ScheduleLabel>

Implementations

Source

impl ModSchedule

pub fn new_custom(name: impl ToString, schedule: impl ScheduleLabel) -> Self

A custom schedule for the Modloader

  • name must match what the mod registers with via the wit api
  • schedule is the Bevy schedule this represents. This schedule must be added to the Bevy Schedules.

Note: Trying to add mod systems to the setup schedule (which defaults to First, see ModloaderPlugin::set_setup_schedule) Bevy’s First schedule will do nothing since this is the mod setup phase

pub fn schedule_label(&self) -> Interned<dyn ScheduleLabel>

Returns a bevy ScheduleLabel. This can be passed into any methods that accept an impl ScheduleLabel.