pub struct ModloaderPlugin(/* private fields */);Expand description
This plugin adds Wasvy modding support to App
use wasvy::prelude::*;
App::new()
.add_plugins(DefaultPlugins)
.add_plugins(ModloaderPlugin::default())
// etcLooking for next steps? See: Mods
Examples
Run custom schedules
In this example, Wasvy is used to load mods that affect a physics simulation.
In the host:
use wasvy::prelude::*;
#[derive(ScheduleLabel, Clone, Debug, PartialEq, Eq, Hash, Default)]
struct SimulationStart;
// The schedule must be added to the world's Schedules Resource
app.add_schedule(Schedule::new(SimulationStart));
app.add_plugins(
// We don't want mods to run systems in any other schedules
ModloaderPlugin::unscheduled()
.enable_schedule(ModSchedule::FixedUpdate)
.enable_schedule(ModSchedule::new_custom("simulation-start", SimulationStart))
);In the mod:
fn setup(){
..
app.add_systems(&Schedule::FixedUpdate, vec![..]);
app.add_systems(&Schedule::Custom("simulation-start".to_string()), vec![..]);
// This one will be ignored and throw a warning
app.add_systems(&Schedule::PreUpdate, vec![..]);
}Implementations
Sourceimpl ModloaderPlugin
impl ModloaderPlugin
Sourcepub fn new(schedules: ModSchedules) -> Self
pub fn new(schedules: ModSchedules) -> Self
Creates a new modloader that will schedule mods be run during the provided Schedules
Sourcepub fn unscheduled() -> Self
pub fn unscheduled() -> Self
Creates plugin with no schedules.
This means that by default loaded mods will not run unless you enable schedules manually using ModloaderPlugin::enable_schedule
If you want wasvy to run on all schedules use ModloaderPlugin::default() or ModloaderPlugin::new
Sourcepub fn set_despawn_behaviour(
self,
despawn_behaviour: ModDespawnBehaviour,
) -> Self
pub fn set_despawn_behaviour( self, despawn_behaviour: ModDespawnBehaviour, ) -> Self
Sets the despawn behaviour for when mods are despawned (or reloaded).
The default behaviour is to despawn all entities the mod spawned. See DespawnEntities.
Sourcepub fn enable_schedule(self, schedule: ModSchedule) -> Self
pub fn enable_schedule(self, schedule: ModSchedule) -> Self
Enables a new schedule with the modloader.
When mods add a system to this schedule, then wasvy will automatically add them to the schedule.
If a mod tries to call add_system with an schedule that isn’t enabled this will just produce a warning.
In debug mode, this will panic if the schedule is already added.
Sourcepub fn set_setup_schedule(self, schedule: impl ScheduleLabel) -> Self
pub fn set_setup_schedule(self, schedule: impl ScheduleLabel) -> Self
Configures during which schedule the modloader sets up new systems.
Defaults to Bevy’s First schedule.
Schedules can’t be modified while in use, therefore a schedule can’t both be used to setup mods and run mod systems simultaneously.
Sourcepub fn add_functionality<F>(self, f: F) -> Self
pub fn add_functionality<F>(self, f: F) -> Self
Use this function to add custom functionality that will be passed to the WASM module.
Sourcepub fn with_codec(self, codec: impl WasvyCodec) -> Self
pub fn with_codec(self, codec: impl WasvyCodec) -> Self
Apply a custom codec for serializing data to/from mods
Defaults to [JsonCodec]